@@ -25,7 +25,10 @@ estVarComp <- function(GLSMethod,
   }
   if (remlAlgo == "EMMA") {
     EMMADat <- pheno[, c("genotype", trait)]
-    EMMACovar <- as.data.frame(pheno[covar], row.names = pheno[["genotype"]])
+    ## Don't add rownames directly when creating data.frame because of 
+    ## https://github.com/tidyverse/tibble/issues/1202
+    EMMACovar <- as.data.frame(pheno[covar])
+    rownames(EMMACovar) <- pheno[["genotype"]]
     if (GLSMethod == "single") {
       remlObj <- EMMA(dat = EMMADat, trait = trait, covar = EMMACovar, K = K)
       ## Extract varComp and vcovMatrix
