@@ -20,6 +20,10 @@
 #' @param X An n x m marker matrix with genotypes in the rows (n) and markers in
 #' the columns (m).
 #' @param method The method used for computing the kinship matrix. 
+#' @param MAF The minor allele frequency (MAF) threshold used in kinship 
+#' computation. A numerical value between 0 and 1. SNPs with MAF below this 
+#' value are not taken into account when computing the kinship. If NULL all 
+#' markers are used regardless of their allele frequency. 
 #' @param denominator A numerical value. See details.
 #'
 #' @return An n x n kinship matrix.
@@ -33,19 +37,23 @@
 #'
 #' @examples 
 #' ## Create example matrix.
-#' M <- matrix(c(1, 1, 0, 0, 1, 1, 0, 0, 0, 1, 0, 1), nrow = 3)
+#' M <- matrix(c(1, 1, 1, 0, 0, 0, 1, 1, 0, 0, 0, 0, 1, 0, 1, 1), nrow = 4)
 #' 
 #' ## Compute kinship matrices using different methods.
 #' kinship(M, method = "astle")
 #' kinship(M, method = "IBS")
 #' kinship(M, method = "vanRaden")
 #' 
+#' ## Only use markers with a Minor Allele Frequency of 0.3 or more.
+#' kinship(M, method = "astle", MAF = 0.3)
+#' 
 #' ## Compute kinship matrix using astle and balding method with denominator 2.
 #' kinship(M, method = "astle", denominator = 2)
 #'
 #' @export
 kinship <- function(X,
                     method = c("astle", "IBS", "vanRaden", "identity"),
+                    MAF = NULL,
                     denominator = NULL) {
   method = match.arg(method)
   chkMarkers(X)
@@ -56,7 +64,7 @@ kinship <- function(X,
     K <- diag(nrow = nrow(X), ncol = nrow(X))
   } else {
     K <- do.call(what = paste0(method, "CPP"),
-                 args = list(x = X, denom = denominator))
+                 args = list(x = X, MAF = MAF, denom = denominator))
   }
   rownames(K) <- colnames(K) <- rownames(X)
   return(K)
